civ.club - News

- Регистрация
- Помощь
- Запомнить?

1. Добро пожаловать, коллега! Если зарегистрировались до 5 ноября 2010, то попробуйте зайти со старыми логином и паролем. Если не получится, то запросите пароль через форму восстановления пароля. Если Вы впервые начинаете работать с сайтовым движком vbulletin, то полистайте FAQ. Перед созданием сообщения следует зарегистрироваться.

- ### Навигация по разделам

- ### Категории статей

  Новости играла (267)
  Новости реала (87)
  Новости сайта (107)
  Рейтинг игроков (45)
  Хранилище файлов (27)

- ### Последние статьи

  #### Youtube-канал sempris2008 с записями игр по Civilization V

  Всем привет.
  Завел свой игровой канал с записями игр в Civilization V: https://www.youtube.com/user/sempris2008/
  На данный момент, в основном дуэли.... подробнее
  Sempris 19.11.2015, 14:07

  #### Категории:

  Новости реала Новости играла

- # Новости

  ### Youtube-канал sempris2008 с записями игр по Civilization V

  Sempris
  - Просмотр профиля
  - Сообщения форума
  - Личное сообщение
  - Записи в дневнике
  - Просмотр статей
  Опубликовано 19.11.2015 14:07 Число просмотров: 278
  Категории:
  1. Новости реала,
  2. Новости играла
  Всем привет.
  Завел свой игровой канал с записями игр в Civilization V: https://www.youtube.com/user/sempris2008/
  На данный момент, в основном дуэли.
  Ранние видео еще без голоса (комментариев), более новые - уже с ними.
  Профи-скиллом не обладаю, но если у вас есть желание потратить время на просмотр игр в циву - то велком
  Подписывайтесь, если вам понравился контент. Буду стараться выкладывать новые видео еженедельно или даже чаще (если будет получаться).
  Пожелания/замечания прошу оставлять в комментариях к видео.
  Спасибо за внимание
  4 Комментарии

  ### Вышла книга по мотивам игры в Civilization

  Gnomig
  - Просмотр профиля
  - Сообщения форума
  - Личное сообщение
  - Записи в дневнике
  - Просмотр статей
  Опубликовано 04.11.2015 14:54
  Категории:
  1. Новости реала
  http://civilizationbook.ru
  Сам являлся в 90х поклонником civ1, так что книга с душой
  Большой кусок текста есть тут: http://samlib.ru/g/gnom_g_g/a_civ_all.shtml
  наслаждайтесь )
  ***

  ### ...очки, дешевые науки и безопасность

  BuDDaH
  - Просмотр профиля
  - Сообщения форума
  - Личное сообщение
  - Записи в дневнике
  - Просмотр статей
  Опубликовано 21.10.2015 17:31 Число просмотров: 519
  Категории:
  1. Новости реала,
  2. Новости играла
  ...
  Хорошо быть адвокатом лидера однополярного мира. Безопасно, легко, удобно, выгодно. Излагаешь правильную точку зрения, тебе хлопают и говорят: "Гут, Вальдемар, зер гут"
  Испанцы так в свои питбоссы играют. Добровольно становятся вассалом лидера, получая очки, дешевые науки и безопасность.
  ...
  Сообщение от Али Гарх
  Но потом то они освобождаются? Или так рабами и остаются?
  Формально не становятся вассалами. Но поведение вассальное до конца. Поддерживают в войнах, меняются технологиями, ресурсами, за победу с лидером не борются. Соревнуются между собой за второе место, кто больше продаст великих людей и денег для финансирования науки лидера. Называют себя друзьями. У меня сейчас в игре 7 таких друзей из 10 соперников. Бедная Индия, бывшая второй, которая решила сплотить мир против гегемонии Франции, сейчас попала под общее эмбарго и сильно отстала от вассалов. Держит огромную армию, сопоставимую с французской, и только это ее спасает от завоевания. Экономика Индии - где-то 10% от Франции.
  ***
  5 Комментарии

  ### Внимание, игроки и любители Civilization 4!

  Ostap352
  - Просмотр профиля
  - Сообщения форума
  - Личное сообщение
  - Записи в дневнике
  - Просмотр статей
  Опубликовано 15.09.2015 20:34 Число просмотров: 357
  Категории:
  1. Новости играла
  Стартовал украинский товарищеский ПБЕМ по Civilization IV по моду RedForce.SB. Походово описываю стратегию и тактику своей игры. Жду ваших советов и комментариев! http://www.civfanatics.ru/threads/11...254#post492254

  ### Всё равно скатились: Реал и Цива5

  Triver
  - Просмотр профиля
  - Сообщения форума
  - Личное сообщение
  - Записи в дневнике
  - Просмотр статей
  Опубликовано 07.09.2015 01:35
  Недавно читал Пикабу и наткнулся на сеи идеи. В общем, всё равно скатился сайт в политоту, так пусть ...
  Подробнее 8 Комментарии

  ### Посоветуйте, что почитать?

  Сержи Кэлли
  - Просмотр профиля
  - Сообщения форума
  - Личное сообщение
  - Записи в дневнике
  - Просмотр статей
  Опубликовано 25.08.2015 14:46 Число просмотров: 329
  Категории:
  1. Новости реала
  Здравствуйте
  Не вижу на форуме темы для приветствия, потому отмечусь в форумской теме Что почитать?
  О себе: поклонник игр серии Цивилизация с большим стажем, скажу сразу по сети не играл - может зря. В последние годы занялся писательской деятельностью и несколько месяцев назад выставил в Самиздате написанное ранее. Так что сейчас мой статус "начинающий автор в поисках целевой аудитории", наткнулся на ваш форум и подумал вдруг это вы. Так как сам являюсь фанатом любых стратегических игр, то и пишу соответственно, ориентируюсь на Дэвида Вебера и Л. М. Буджолд. Да еще новый роман "Акварель тенью" написан из идеи предположения, что нашим миром и цивилизациями в нем управляют боги, конкретно древние шумерские. Может слишком переиграл в Циву!
  Если кого-то заинтересовал, то буду рад если вы посетите мой раздел в Самиздате, если что-нибудь прочитаете и оставите коммент, то буду рад вдвойне
  ссылка: http://samlib.ru/editors/s/serzhi_k/
  ***
  1 Комментарий

  ### Инфоцентр Civilization: Beyond Earth

  m_kus
  - Просмотр профиля
  - Сообщения форума
  - Личное сообщение
  - Записи в дневнике
  - Просмотр статей
  Опубликовано 14.08.2015 14:27 Число просмотров: 625
  Категории:
  1. Новости играла
  http://store.steampowered.com/app/65980/
  * Открыт предзаказ Civilization: Beyond Earth expansion Rising Tide (899 рублей).
  Дата выхода аддона: 9 октября 2015

  ### ... эта категория людей тихо дохнет от голода? Суки, а не правители

  lada
  - Просмотр профиля
  - Сообщения форума
  - Личное сообщение
  - Записи в дневнике
  - Просмотр статей
  Опубликовано 03.08.2015 09:16 Число просмотров: 1830
  Категории:
  1. Новости реала
  Читаю в новостях:
  Жителям Подмосковья, которые нуждаются в лечении в Москве или имеют доход ниже прожиточного минимума, планируется сохранить льготы на проезд в московском транспорте.
  А вот интересно, тех, кто отменяет бесплатный проезд для пенсионеров, а потом выдает в эфир вот такие поправки, не смущает сама формулировка ДОХОД НИЖЕ ПРОЖИТОЧНОГО МИНИМУМА? Это означает что? Что эта категория людей тихо дохнет от голода? Суки, а не правители.
  ***
  Президент России Владимир Путин подписал указ об уничтожении ввезенных в Россию и подпадающих под эмбарго продуктов.
  Что делается-то, православные? Жратву уничтожают. На радость, видимо, тем, у кто доход ниже прожиточного уровня. Сволочи. А таможню не проще призвать к порядку, раз уж. Как это так "ввезенные в Россию"?! Куда эта чертова таможня смотрит?
  ***
  Многое может простить русский человек, но уничтожать еду... Нравственное уродство это. Странно то, что такой закон подписывает человек, родившийся в Питере. У меня куча родственников - коренных ленинградцев, так вот для них блокада - это пунктик, причем, независимо от возраста, потому как блокада каждой семьи коснулась. И в Питере из-за блокады к еде особое отношение. В общем, такой указ - явный симптом того, что у дракона башка повредилась.
  ***
  Во, видали?
  Правительство разрешило уничтожать санкционные продукты, незаконно ввозимые в Россию, «любым доступным способом». Процесс уничтожения будет необходимо фиксировать на видео в присутствии независимых свидетелей.
  Дмитрий Анатольевич подключился. Небось, сам ни одной морковки в жизни не вырастил.
  Вообще все это уже напоминает фильм "Фонтан". Трубы замерзли, а это объявляют акцией экономии, а когда дом уже рушится, к "акции" подключается заодно и электрик. "Любым доступным способом"? Супер. Предлагаю скармливать бешеным собакам на глазах у малоимущих.
  ***
  25 Комментарии

  ### Питбосс по игре Civilization IV Beyond the Sword.

  pioner
  - Просмотр профиля
  - Сообщения форума
  - Личное сообщение
  - Записи в дневнике
  - Просмотр статей
  Опубликовано 30.07.2015 08:57
  Уважаемые форумчане!
  Доброго всем времени суток! На немецком ресурсе http://civ.zulan.net/pb проводится Питбосс ...
  Подробнее

  ### Вторая форумная игра в браузерку Call of War

  Diman000
  - Просмотр профиля
  - Сообщения форума
  - Личное сообщение
  - Записи в дневнике
  - Просмотр статей
  Опубликовано 07.07.2015 09:04
  Осталось одно вакантное место во вторую игру в Call of War!
  Записываемся тут:
  http://www.civfanatics.ru/threads/11889-Call-Of-War-2 ...
  Подробнее

  ### Первая форумная игра в браузерку Call of War

  Али Гарх
  - Просмотр профиля
  - Сообщения форума
  - Личное сообщение
  - Записи в дневнике
  - Просмотр статей
  Опубликовано 27.06.2015 12:30 Число просмотров: 689
  Категории:
  1. Новости реала,
  2. Новости играла
  Всем, Всем, Всем!
  На 1 июля 20:00 берлинского времени назначен старт приватной форумной игры в Call of War (аналог Panzer General в браузере).
  Уже записались: Виго, Снейк, Ястреб, КБ, Будда, Аруджи и я. Ещё нужно несколько человек (карта на 10 игроков).
  Отпуск в пару недель не проблема. Если есть доступ к интернету хотя бы раз в день, этого достаточно чтобы поддерживать экономику на ходу. От войн на время отпуска можно отказаться заключив со всеми мир, джентльмены думаю в такой мелочи не откажут.
  Записываемся тут >>>
  ***

  ### В Стиме скидка на Sid Meier's Civilization: Beyond Earth 60%

  S1LENT
  - Просмотр профиля
  - Сообщения форума
  - Личное сообщение
  - Записи в дневнике
  - Просмотр статей
  Опубликовано 14.06.2015 23:11 Число просмотров: 1560
  Категории:
  1. Новости играла
  В Стиме действует скидка 60%, т.е. за 799 руб. можно взять. На время написания поста, до окончания распродажи оставалось 45 часов. Поторопитесь!
  Sid Meier's Civilization: Beyond Earth 799 руб.
  Sid Meier's Civilization: Beyond Earth Classics Bundle 1007 руб.
  Sid Meier's Starships and Civilization: Beyond Earth 887 руб.
  7 Комментарии

  ### Замена стартового сейва Гран-При "Цив! Труд! Май 2015!"

  as239
  - Просмотр профиля
  - Сообщения форума
  - Личное сообщение
  - Записи в дневнике
  - Просмотр статей
  Опубликовано 12.05.2015 18:34 Число просмотров: 903
  Категории:
  1. Новости играла
  Внимание! Первоначальный сейв, изменен 07.05.2015.
  Всем, кто скачивал в этот день и раньше, нужно взять новый сейв.
  Основные изменения:
  - Уменьшено количество люксов до 7-ми
  - У столицы убраны одно железо и одна лошадь
  - Количество алюминия на Урале уменьшено с 7 до 3-х
  - Количество урана во всех месторождениях уменьшено с 4-х до 2-х
  ***

  ### Экономика. Обменный курс ресурсов Civ5

  Wasya
  - Просмотр профиля
  - Сообщения форума
  - Личное сообщение
  - Записи в дневнике
  - Просмотр статей
  Опубликовано 04.05.2015 22:50 Число просмотров: 1176
  Категории:
  1. Техподдержка Civ5,
  2. Новости играла
  У империи, с которой заключена декларация дружбы, можно взять деньги в долг. Берем 25 монеток, возвращаем 1 монетку в течение 30-ти ходов.
  По этой операции можно рассчитать фундаментальный показатель для любой экономики.
  Ставка рефинансирования центрального банка игры Sid Meier's Civilization V = 1,21908264% в ход.
  ***

  ### Турнир офлайн с перезагрузками Гран-При "Цив! Труд! Май 2015!"

  as239
  - Просмотр профиля
  - Сообщения форума
  - Личное сообщение
  - Записи в дневнике
  - Просмотр статей
  Опубликовано 01.05.2015 14:09 Число просмотров: 1064
  Категории:
  1. Новости играла,
  2. Рейтинг игроков

  ### Предлагаю всем желающим, отметить майские праздники трудовыми достижениями в Sid Meier's Civilization V.

  Что для этого нужно сделать:
  1. Скачать сейв:
     Catherine_0000 BC-4000.zip ЗАМЕНЕН 7 мая на исправленный, качать этот Catherine_0000 BC-4000.zip
     Участник турнира обязан хранить все ежеходные автосейвы или вручную сделанные сейвы
     и финишный файл в течение месяца по окончании игры.
  2. Получить в окне демографии 1000 и больше молотков.
  Условия:
  - Разрешено построить только 3-и Чуда света (национальные без ограничений).
  - Запрещено строить чудо Пизанская башня
  - Запрещено встречать ИИ
  - В победный ход - ни один город не должен голодать
  - В победный ход - население каждого города должно быть как минимум 6 жителей
  Настройки:
  - Скорость - Быстрая
  - Карта - Пангея
  - Уровень моря - Высокий
  - ИИ - Считайте что нет
  - Варвары - Нет
  - Руины- Нет
  Минимум рэндома - максимум стратегии!
  Призовой фонд:
  1-е место - 1500 р.
  2-е место - 700 р.
  3-е место - 300 р.
  Срок: 07.06.2015 до 20.00 МСК.
  Победный сейв называем своим ником и отправляем на as239*list.ru.
  Тема письма: Турнир "Цив! Труд! Май!"
  При равенстве ходов победитель определяется по большему количеству молотков.
  При равенстве молотков побеждает игрок с меньшим количеством городов.
  При равном количестве городов побеждает игрок с меньшим количеством жителей.
  обсуждение в теме:

  Страница 1 из 26 1 2 11 ... Последняя
  - К странице: